@@ -6,7 +6,7 @@ require 'cgi'
 
 # expose shortcut methods
 module Curl
-  
+
   def self.http(verb, url, post_body=nil, put_data=nil, &block)
     handle = Thread.current[:curb_curl] ||= Curl::Easy.new
     handle.reset
@@ -48,7 +48,13 @@ module Curl
 
   def self.urlalize(url, params={})
     uri = URI(url)
-    uri.query = params.map {|k,v| "#{URI.escape(k.to_s)}=#{URI.escape(v.to_s)}" }.join("&")
+    params_query = URI.encode_www_form(params || {})
+    # both uri.query and params_query not blank
+    if !(uri.query.nil? || uri.query.empty?) && !params_query.empty?
+      uri.query = "#{uri.query}&#{params_query}"
+    else
+      uri.query = "#{uri.query}#{params_query}"
+    end
     uri.to_s
   end
 
