@@ -18,7 +18,7 @@ rescue LoadError
 end
 require 'fileutils'
 
-$TEST_URL = "file://#{'/' if RUBY_DESCRIPTION =~ /mswin|msys|mingw|cygwin|bccwin|wince|emc/}#{URI.escape(File.expand_path(__FILE__).tr('\\','/'))}"
+$TEST_URL = "file://#{'/' if RUBY_DESCRIPTION =~ /mswin|msys|mingw|cygwin|bccwin|wince|emc/}#{File.expand_path(__FILE__).tr('\\','/')}"
 
 require 'thread'
 require 'webrick'
@@ -30,19 +30,22 @@ require 'webrick'
 TEST_SINGLE_THREADED=false
 
 # keep webrick quiet
-class ::WEBrick::HTTPServer
+::WEBrick::HTTPServer.send(:remove_method,:access_log) if ::WEBrick::HTTPServer.instance_methods.include?(:access_log)
+::WEBrick::BasicLog.send(:remove_method,:log) if ::WEBrick::BasicLog.instance_methods.include?(:log)
+
+::WEBrick::HTTPServer.class_eval do
   def access_log(config, req, res)
     # nop
   end
 end
-class ::WEBrick::BasicLog
+::WEBrick::BasicLog.class_eval do
   def log(level, data)
     # nop
   end
 end
 
 #
-# Simple test server to record number of times a request is sent/recieved of a specific 
+# Simple test server to record number of times a request is sent/recieved of a specific
 # request type, e.g. GET,POST,PUT,DELETE
 #
 class TestServlet < WEBrick::HTTPServlet::AbstractServlet
@@ -147,7 +150,7 @@ module TestServerMethods
           rd.close
           rd = nil
 
-          # start up a webrick server for testing delete 
+          # start up a webrick server for testing delete
           server = WEBrick::HTTPServer.new :Port => port, :DocumentRoot => File.expand_path(File.dirname(__FILE__))
 
           server.mount(servlet.path, servlet)
@@ -163,7 +166,7 @@ module TestServerMethods
         rd.read
         rd.close
       else
-        # start up a webrick server for testing delete 
+        # start up a webrick server for testing delete
         @server = WEBrick::HTTPServer.new :Port => port, :DocumentRoot => File.expand_path(File.dirname(__FILE__))
 
         @server.mount(servlet.path, servlet)
